/*************************************************************************\
* Copyright (c) 2002 The University of Chicago, as Operator of Argonne
* National Laboratory.
* Copyright (c) 2002 The Regents of the University of California, as
* Operator of Los Alamos National Laboratory.
* This file is distributed subject to a Software License Agreement found
* in the file LICENSE that is included with this distribution. 
\*************************************************************************/
/**** SCCS ID: @(#)ccp.c	1.1 10/21/93 ****/
/*********************************************************************
 * FILE:      configure_client_process.c
 * FUNCTIONS: configure_client_process(), process_cmdline_args()
 * AUTHOR:    Claude Saunders, APS Controls Group
 * Purpose:   Initializes process environment.
 *            Gets command line args. Signal handlers reside here.
 *********************************************************************/

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <signal.h>

#include "localdefs.h"

/* For cmdline argument processing */
extern char *optarg;
extern int optind;

extern FILE *errlog;
extern int verbose;           /* verbosity flag */
extern int debug;             /* debug level    */
extern int timeout;           /* communications timeout flag    */

/*************************************************************************
 * FUNCTION : configure_client_process()
 * PURPOSE  : Set up execution environment.
 *            
 * ARGS in  : none
 * ARGS out : none
 * GLOBAL   : 
 * RETURNS  : NERROR - complete
 ************************************************************************/  
int
configure_client_process()
{
  int sig_term();
  int sig_alarm();
  int sig_pipe();

  verbose = 0;
  debug = 0;
  timeout = 0;

  return(NERROR);
}

/*************************************************************************
 * FUNCTION : process_cmdline_args()
 * PURPOSE  : Get command line arguments. If specified, set global verbose
 *            and debug flags.
 * ARGS in  : argc, argv - standard unix
 * ARGS out : msg: optional message to be used for backup/restore
 * GLOBAL   : Sets global verbose and debug flags. Usage error results
 *            in message to stderr and exit with code of EXIT_ERROR.
 * RETURNS  : NERROR - complete
 ************************************************************************/  
int
process_cmdline_args(int argc, char *argv[], char *msg)
{
  int c;
  int cmderror = 0;
  double atof();
  void usage();

  /* Process command line options */
  while ((c=getopt(argc,argv,"m:d:")) != -1)
    switch(c) {
    case 'd': debug = atoi(optarg);
              if (debug < 1 || debug > 3) cmderror++;
              break;
    case 'm': strcpy(msg,optarg);
              break;
    default:  cmderror++;
    }

  if (cmderror) {
    usage(argv[0]);
    exit(EXIT_ERROR);
  }

  return(NERROR);
}

/*************************************************************************
 * FUNCTION : sig_term()
 * PURPOSE  : Handle SIGTERM signal. Logs termination
 * ARGS in  : none
 * ARGS out : none
 * GLOBAL   : 
 * RETURNS  : none
 ************************************************************************/
int sig_term()
{
  fprintf(errlog,"Process exiting due to SIGTERM\n");
  exit(EXIT_ERROR);
}

/*************************************************************************
 * FUNCTION : sig_alarm()
 * PURPOSE  : Handle SIGALRM signal. When a socket recv() or send() call
 *            gets stuck, this function is invoked. Timeout is in seconds
 *            and is specified by ALRMTMOUT.  Timeout flag is set and is
 *            checked whenever a socket recv() or send() returns.
 * ARGS in  : none
 * ARGS out : none
 * GLOBAL   : Sets global variable "timeout".
 * RETURNS  : none
 ************************************************************************/
int sig_alarm()
{
  fprintf(errlog," CLIENT communications timeout\n");
  fflush(errlog);
}

/*************************************************************************
 * FUNCTION : sig_pipe()
 * PURPOSE  : Handle SIGPIPE signal. This usually only occurs when
 *            you attempt a socket send() on a closed or closing sd.
 *            Only need to log what happened, since currently executing
 *            send() call will return an error.
 * ARGS in  : none
 * ARGS out : none
 * GLOBAL   : Server SComLog is written to.
 * RETURNS  : none
 ************************************************************************/
int sig_pipe()
{
  fprintf(errlog,"CLIENT received SIGPIPE\n");
  fflush(errlog);
}

/*************************************************************************
 * FUNCTION : usage()
 * PURPOSE  : Describes command line options available to client.
 * ARGS in  : char *name - name of executable program
 * ARGS out : none
 * GLOBAL   : Errlog written to.
 * RETURNS  : none
 ************************************************************************/  
void usage(name)
     char *name;
{
  fprintf(errlog,"\nusage: %s [-m msg]\n",name);
  fprintf(errlog,"purpose:\tTakes a spec-file from stdin and generates a\n");
  fprintf(errlog,"        \tsnapshot file to stdout.\n");
  fprintf(errlog,"options:\n");
  fprintf(errlog,"\t-m <msg>\n");
  fprintf(errlog,"\t\tsend <msg> to device instead of default read\n");
  fprintf(errlog,"\t-d <level>\n");
  fprintf(errlog,"\t\tset debug to <level>\n");
}









